@@ -1,7 +1,10 @@
 //! Version 2, Community Version (RFC 1901)
-use rasn::{AsnType, Decode, Encode, types::{Integer, OctetString}};
+use rasn::{
+    types::{Integer, OctetString},
+    AsnType, Decode, Encode,
+};
 
-#[derive(AsnType, Debug, Clone, Decode, Encode)]
+#[derive(AsnType, Debug, Clone, Decode, Encode, PartialEq, PartialOrd, Eq, Ord, Hash)]
 pub struct Message<T> {
     pub version: Integer,
     pub community: OctetString,
